@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Use `Varstack <https://github.com/conversis/varstack>`_ data as a Pillar source
 
 Configuring Varstack
@@ -17,7 +17,7 @@ Varstack will then use /etc/varstack.yaml to determine which configuration
 data to return as pillar information. From there you can take a look at the
 `README <https://github.com/conversis/varstack/blob/master/README.md>`_ of
 varstack on how this file is evaluated.
-'''
+"""
 
 from __future__ import absolute_import, print_function, unicode_literals
 
@@ -27,21 +27,21 @@ except ImportError:
     varstack = None
 
 # Define the module's virtual name
-__virtualname__ = 'varstack'
+__virtualname__ = "varstack"
 
 
 def __virtual__():
     return (
         varstack and __virtualname__ or False,
-        'The varstack module could not be loaded: varstack dependency is missing.'
+        "The varstack module could not be loaded: varstack dependency is missing.",
     )
 
 
-def ext_pillar(minion_id,  # pylint: disable=W0613
-               pillar,  # pylint: disable=W0613
-               conf):
-    '''
+def ext_pillar(
+    minion_id, pillar, conf  # pylint: disable=W0613  # pylint: disable=W0613
+):
+    """
     Parse varstack data and return the result
-    '''
+    """
     vs = varstack.Varstack(config_filename=conf)
     return vs.evaluate(__grains__)
