@@ -1,26 +1,20 @@
-# -*- coding: utf-8 -*-
 """
 Tests for the salt fileclient
 """
 
-# Import Python libs
-from __future__ import absolute_import
 
 import errno
 import logging
 import os
 import shutil
 
-# Import Salt libs
 import salt.utils.files
 from salt import fileclient
-from salt.ext import six
-from salt.ext.six.moves import range
-from tests.integration import AdaptedConfigurationTestCaseMixin
-from tests.support.mixins import LoaderModuleMockMixin
+from tests.support.mixins import (
+    AdaptedConfigurationTestCaseMixin,
+    LoaderModuleMockMixin,
+)
 from tests.support.mock import MagicMock, Mock, patch
-
-# Import Salt Testing libs
 from tests.support.runtests import RUNTIME_VARS
 from tests.support.unit import TestCase
 
@@ -39,7 +33,7 @@ class FileclientTestCase(TestCase):
 
     def _fake_makedir(self, num=errno.EEXIST):
         def _side_effect(*args, **kwargs):
-            raise OSError(num, "Errno {0}".format(num))
+            raise OSError(num, "Errno {}".format(num))
 
         return Mock(side_effect=_side_effect)
 
@@ -69,6 +63,24 @@ class FileclientTestCase(TestCase):
                     ) as c_ref_itr:
                         assert c_ref_itr == "/__test__/files/base/testfile"
 
+    def test_cache_extrn_path_valid(self):
+        """
+        Tests for extrn_filepath for a given url
+        """
+        file_name = "http://localhost:8000/test/location/src/dev/usr/file"
+
+        ret = fileclient.Client(self.opts)._extrn_path(file_name, "base")
+        assert ret == os.path.join("__test__", "extrn_files", "base", ret)
+
+    def test_cache_extrn_path_invalid(self):
+        """
+        Tests for extrn_filepath for a given url
+        """
+        file_name = "http://localhost:8000/../../../../../usr/bin/bad"
+
+        ret = fileclient.Client(self.opts)._extrn_path(file_name, "base")
+        assert ret == "Invalid path"
+
     def test_extrn_path_with_long_filename(self):
         safe_file_name = os.path.split(
             fileclient.Client(self.opts)._extrn_path(
@@ -99,7 +111,7 @@ SUBDIR_FILES = ("foo.txt", "bar.txt", "baz.txt")
 
 
 def _get_file_roots(fs_root):
-    return dict([(x, [os.path.join(fs_root, x)]) for x in SALTENVS])
+    return {x: [os.path.join(fs_root, x)] for x in SALTENVS}
 
 
 class FileClientTest(
@@ -201,7 +213,7 @@ class FileclientCacheTest(
 
             path = os.path.join(saltenv_root, "foo.txt")
             with salt.utils.files.fopen(path, "w") as fp_:
-                fp_.write("This is a test file in the '{0}' saltenv.\n".format(saltenv))
+                fp_.write("This is a test file in the '{}' saltenv.\n".format(saltenv))
 
             subdir_abspath = os.path.join(saltenv_root, SUBDIR)
             os.makedirs(subdir_abspath)
@@ -209,8 +221,8 @@ class FileclientCacheTest(
                 path = os.path.join(subdir_abspath, subdir_file)
                 with salt.utils.files.fopen(path, "w") as fp_:
                     fp_.write(
-                        "This is file '{0}' in subdir '{1} from saltenv "
-                        "'{2}'".format(subdir_file, SUBDIR, saltenv)
+                        "This is file '{}' in subdir '{} from saltenv "
+                        "'{}'".format(subdir_file, SUBDIR, saltenv)
                     )
 
         # Create the CACHE_ROOT
@@ -220,16 +232,14 @@ class FileclientCacheTest(
         """
         Ensure entire directory is cached to correct location
         """
-        patched_opts = dict((x, y) for x, y in six.iteritems(self.minion_opts))
+        patched_opts = {x: y for x, y in self.minion_opts.items()}
         patched_opts.update(self.MOCKED_OPTS)
 
         with patch.dict(fileclient.__opts__, patched_opts):
             client = fileclient.get_file_client(fileclient.__opts__, pillar=False)
             for saltenv in SALTENVS:
                 self.assertTrue(
-                    client.cache_dir(
-                        "salt://{0}".format(SUBDIR), saltenv, cachedir=None
-                    )
+                    client.cache_dir("salt://{}".format(SUBDIR), saltenv, cachedir=None)
                 )
                 for subdir_file in SUBDIR_FILES:
                     cache_loc = os.path.join(
@@ -259,7 +269,7 @@ class FileclientCacheTest(
         Ensure entire directory is cached to correct location when an alternate
         cachedir is specified and that cachedir is an absolute path
         """
-        patched_opts = dict((x, y) for x, y in six.iteritems(self.minion_opts))
+        patched_opts = {x: y for x, y in self.minion_opts.items()}
         patched_opts.update(self.MOCKED_OPTS)
         alt_cachedir = os.path.join(RUNTIME_VARS.TMP, "abs_cachedir")
 
@@ -268,7 +278,7 @@ class FileclientCacheTest(
             for saltenv in SALTENVS:
                 self.assertTrue(
                     client.cache_dir(
-                        "salt://{0}".format(SUBDIR), saltenv, cachedir=alt_cachedir
+                        "salt://{}".format(SUBDIR), saltenv, cachedir=alt_cachedir
                     )
                 )
                 for subdir_file in SUBDIR_FILES:
@@ -295,7 +305,7 @@ class FileclientCacheTest(
         Ensure entire directory is cached to correct location when an alternate
         cachedir is specified and that cachedir is a relative path
         """
-        patched_opts = dict((x, y) for x, y in six.iteritems(self.minion_opts))
+        patched_opts = {x: y for x, y in self.minion_opts.items()}
         patched_opts.update(self.MOCKED_OPTS)
         alt_cachedir = "foo"
 
@@ -304,7 +314,7 @@ class FileclientCacheTest(
             for saltenv in SALTENVS:
                 self.assertTrue(
                     client.cache_dir(
-                        "salt://{0}".format(SUBDIR), saltenv, cachedir=alt_cachedir
+                        "salt://{}".format(SUBDIR), saltenv, cachedir=alt_cachedir
                     )
                 )
                 for subdir_file in SUBDIR_FILES:
@@ -335,7 +345,7 @@ class FileclientCacheTest(
         """
         Ensure file is cached to correct location
         """
-        patched_opts = dict((x, y) for x, y in six.iteritems(self.minion_opts))
+        patched_opts = {x: y for x, y in self.minion_opts.items()}
         patched_opts.update(self.MOCKED_OPTS)
 
         with patch.dict(fileclient.__opts__, patched_opts):
@@ -365,7 +375,7 @@ class FileclientCacheTest(
         Ensure file is cached to correct location when an alternate cachedir is
         specified and that cachedir is an absolute path
         """
-        patched_opts = dict((x, y) for x, y in six.iteritems(self.minion_opts))
+        patched_opts = {x: y for x, y in self.minion_opts.items()}
         patched_opts.update(self.MOCKED_OPTS)
         alt_cachedir = os.path.join(RUNTIME_VARS.TMP, "abs_cachedir")
 
@@ -394,7 +404,7 @@ class FileclientCacheTest(
         Ensure file is cached to correct location when an alternate cachedir is
         specified and that cachedir is a relative path
         """
-        patched_opts = dict((x, y) for x, y in six.iteritems(self.minion_opts))
+        patched_opts = {x: y for x, y in self.minion_opts.items()}
         patched_opts.update(self.MOCKED_OPTS)
         alt_cachedir = "foo"
 
@@ -428,7 +438,7 @@ class FileclientCacheTest(
         """
         Tests functionality for cache_dest
         """
-        patched_opts = dict((x, y) for x, y in six.iteritems(self.minion_opts))
+        patched_opts = {x: y for x, y in self.minion_opts.items()}
         patched_opts.update(self.MOCKED_OPTS)
 
         relpath = "foo.com/bar.txt"
@@ -445,7 +455,7 @@ class FileclientCacheTest(
             )
 
         def _check(ret, expected):
-            assert ret == expected, "{0} != {1}".format(ret, expected)
+            assert ret == expected, "{} != {}".format(ret, expected)
 
         with patch.dict(fileclient.__opts__, patched_opts):
             client = fileclient.get_file_client(fileclient.__opts__, pillar=False)
